@@ -1,7 +1,4 @@
 package Bot::BasicBot::Pluggable::Store::DBI;
-BEGIN {
-  $Bot::BasicBot::Pluggable::Store::DBI::VERSION = '0.88';
-}
 use warnings;
 use strict;
 use Carp qw( croak );
@@ -31,6 +28,9 @@ sub create_table {
     my $self  = shift;
     my $table = $self->{table} or die "Need DB table";
     my $sth   = $self->dbh->table_info( '', '', $table, "TABLE" );
+
+	$table = $self->dbh->quote_identifier($table);
+
     if ( !$sth->fetch ) {
         $self->dbh->do(
             "CREATE TABLE $table (
@@ -52,6 +52,9 @@ sub create_table {
 sub get {
     my ( $self, $namespace, $key ) = @_;
     my $table = $self->{table} or die "Need DB table";
+
+	$table = $self->dbh->quote_identifier($table);
+
     my $sth = $self->dbh->prepare_cached(
         "SELECT store_value FROM $table WHERE namespace=? and store_key=?");
     $sth->execute( $namespace, $key );
@@ -64,6 +67,9 @@ sub get {
 sub set {
     my ( $self, $namespace, $key, $value ) = @_;
     my $table = $self->{table} or die "Need DB table";
+
+	$table = $self->dbh->quote_identifier($table);
+
     $value = nfreeze($value) if ref($value);
     if ( defined( $self->get( $namespace, $key ) ) ) {
         my $sth = $self->dbh->prepare_cached(
@@ -85,6 +91,9 @@ sub set {
 sub unset {
     my ( $self, $namespace, $key ) = @_;
     my $table = $self->{table} or die "Need DB table";
+
+	$table = $self->dbh->quote_identifier($table);
+
     my $sth = $self->dbh->prepare_cached(
         "DELETE FROM $table WHERE namespace=? and store_key=?");
     $sth->execute( $namespace, $key );
@@ -105,6 +114,8 @@ sub keys {
     my ( $self, $namespace, %opts ) = @_;
     my $table = $self->{table} or die "Need DB table";
 
+	$table = $self->dbh->quote_identifier($table);
+
     my @res = ( exists $opts{res} ) ? @{ $opts{res} } : ();
 
     my $sql = "SELECT store_key FROM $table WHERE namespace=?";
@@ -140,6 +151,9 @@ sub keys {
 sub namespaces {
     my ($self) = @_;
     my $table = $self->{table} or die "Need DB table";
+
+	$table = $self->dbh->quote_identifier($table);
+
     my $sth =
       $self->dbh->prepare_cached("SELECT DISTINCT namespace FROM $table");
     $sth->execute();
@@ -156,10 +170,6 @@ __END__
 
 Bot::BasicBot::Pluggable::Store::DBI - use DBI to provide a storage backend
 
-=head1 VERSION
-
-version 0.88
-
 =head1 SYNOPSIS
 
   my $store = Bot::BasicBot::Pluggable::Store::DBI->new(
@@ -184,4 +194,4 @@ the values set by modules. Complex values are stored using Storable.
 Mario Domgoergen <mdom@cpan.org>
 
 This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+and/or modify it under the same terms as Perl itself.
